// ------------------------------------------------------------------------------------
// JavaORB 2.0
//
//									CosNaming Browser
//
// (c) 1998, 1999 by Jerome DANIEL
// ------------------------------------------------------------------------------------

import javax.swing.*;
import javax.swing.tree.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

/**
 * This class is a dialog box to insert an object reference from a file
 * 
 * @author	Jerome DANIEL
 * @version	2.0
 */
public class ObjectInsertDialog extends JDialog
{
	/**
	 * Reference to the data
	 */
	private JTextField _name;
	private JTextField _kind;
	private JTextField _path;
	
	/**
	 * Reference to the BROWSE button 
	 */
	private javax.swing.JButton _browse;

	/**
	 * Flag that precises if the cancel button was used
	 */
	private boolean cancel;
	
	/**
	 * Reference to the current path
	 */
	private String currentPath;

	/**
	 * Constructor
	 */
	public ObjectInsertDialog( java.awt.Frame Owner, String title )
	{
		super(Owner, title, true );				
		
		java.io.File file = new java.io.File("foobar");
			
		currentPath = file.getAbsolutePath();
		
		currentPath = currentPath.substring(0, currentPath.lastIndexOf( java.io.File.separator ) );
		
		file.delete();
	
		buildDialog();
	}
				
	/**
	 * Build the dialog window
	 */
	public void buildDialog()
	{
		setSize(500,200);
		
		JPanel panel = new JPanel(false);

		getContentPane().add("Center", panel);

		panel.setLayout( new java.awt.BorderLayout() );

		// ----------------------------
		// Add Name and Kind fields
		// ----------------------------

		JPanel data = new JPanel(false);
		
		java.awt.GridBagConstraints c2 = new java.awt.GridBagConstraints();
		c2.fill = java.awt.GridBagConstraints.BOTH;
		c2.insets = new java.awt.Insets(5, 5, 5, 5);
		
		java.awt.GridBagLayout dataGridbag = new java.awt.GridBagLayout();		
		data.setLayout( dataGridbag );				

		// Name field
		_name = new JTextField();		
		addToPanel(data, new JLabel("Object name"), dataGridbag, c2, 0, 1);		
		addToPanel(data, _name, dataGridbag, c2, 2, java.awt.GridBagConstraints.REMAINDER );				

		// Kind field		
		_kind = new JTextField();
		addToPanel(data, new JLabel("Object kind"), dataGridbag, c2, 0, 1);		
		addToPanel(data, _kind, dataGridbag, c2, 2, java.awt.GridBagConstraints.REMAINDER );				
		
		// Path field		
		_path = new JTextField();
		_browse = new JButton("Browse");
		_browse.addActionListener( new BrowseAction() );
		addToPanel(data, new JLabel("IOR file"), dataGridbag, c2, 0, 1);
		addToPanel(data, _path, dataGridbag, c2, 2, 2);
		addToPanel(data, _browse, dataGridbag, c2, 0, java.awt.GridBagConstraints.REMAINDER );
				
		// --------------------------------
		// Add OK and CANCEL buttons
		// --------------------------------

		JPanel buttons = new JPanel(false);
		
		buttons.setLayout( new java.awt.GridLayout(1,2) );
		buttons.setBorder( new javax.swing.border.EmptyBorder(0,10,5,10) );		

		JButton ok = new JButton("Ok");
		buttons.add(ok);		
		ok.addActionListener( new OkAction() );

		JButton cancel = new JButton("Cancel");
		buttons.add(cancel);
		cancel.addActionListener( new CancelAction() );

		panel.add("Center",data);
		panel.add("South", buttons);			
	}

	/**
	 * Return the naming context name
	 */
	public String getName()
	{
		return _name.getText();
	}

	/**
	 * Return the naming context kind
	 */
	public String getType()
	{
		return _kind.getText();
	}
	
	/**
	 * Return the IOR file path
	 */
	public String getPath()
	{
		return _path.getText();
	}

	/**
	 * Return the flag that precises id the cancel button was used
	 */
	public boolean cancelButton()
	{
		return cancel;
	}

	/**
	 * Event managment for OK
	 */
	public class OkAction extends Object implements ActionListener
	{
		public void actionPerformed( ActionEvent e )
		{
			hide();
			cancel = false;
		}
	}

	/**
	 * Event managment for CANCEL
	 */
	public class CancelAction extends Object implements ActionListener
	{
		public void actionPerformed( ActionEvent e )
		{
			hide();
			cancel = true;
		}
	}
	
	/**
	 * Event managment for BROWSE
	 */
	public class BrowseAction extends Object implements ActionListener
	{
		public void actionPerformed( ActionEvent e )
		{
			javax.swing.JFileChooser chooser = new javax.swing.JFileChooser( currentPath );

			chooser.setFileSelectionMode( javax.swing.JFileChooser.FILES_ONLY );
					
			int ret = chooser.showOpenDialog(null);
			if ( ret == javax.swing.JFileChooser.APPROVE_OPTION ) 
			{
				currentPath = chooser.getSelectedFile().getAbsolutePath().substring(0, chooser.getSelectedFile().getAbsolutePath().lastIndexOf( java.io.File.separator ) );				
				_path.setText( chooser.getSelectedFile().getAbsolutePath() );
			}
		}
	}
	
	/**
	 * This function adds to a panel a new component with a grid bag constraint
	 */
	private void addToPanel( javax.swing.JPanel panel, 
							 javax.swing.JComponent comp, 
							 java.awt.GridBagLayout gridbag, 
							 java.awt.GridBagConstraints c, 
							 int weightx, int gridwidth )
    {
        c.weightx = weightx;
        c.gridwidth = gridwidth;
        gridbag.setConstraints(comp, c);
        panel.add(comp);
    }

	/**
	 * This function is used to display the windows at the screen center
	 */
    public void show()
    {
		java.awt.Dimension screenSize = getToolkit().getScreenSize();
        setLocation((screenSize.width - getSize().width) / 2 , (screenSize.height - getSize().height) / 2);
        
	    super.show();
	}
}