// ===========================================================
//
// This example is extracted from CORBA Specification  9.6.10
// It shows how to use a single servant to manage several
// objects
//
// Jerome DANIEL
// ===========================================================

import java.io.*;

public class FileDescriptorImpl extends FileDescriptorPOA
{
	/**
	 * POA reference
	 */
	private org.omg.PortableServer.POA _poa;

	/**
	 * Constructor
	 *
	 * @param	poa		reference to POA
	 */
	public FileDescriptorImpl( org.omg.PortableServer.POA poa )
	{
		_poa = poa;		
	}

	/**
	 * Operation getDescriptor
	 * 
	 * this operation returns the file descriptor which is the
	 * object id 
	 *
	 * @return	 the file descriptor
	 */
	public DataInputStream getDescriptor()
	{
		byte [] oid = null;

		try
		{			
			org.omg.CORBA.Object current_obj = _orb().resolve_initial_references("POACurrent");
			
			org.omg.PortableServer.Current current = org.omg.PortableServer.CurrentHelper.narrow( current_obj );
			
			oid = current.get_object_id();
		}
		catch ( org.omg.CORBA.ORBPackage.InvalidName ex )
		{
			System.out.println("Impossible de recuperer l'objet current");			
			System.exit(0);
		}
		catch ( org.omg.PortableServer.CurrentPackage.NoContext ex )
		{
			System.out.println("Impossible de recuperer le context");			
			System.exit(0);
		}				

		// Convert this id to string
		String id = new String( oid );

		// Get the descriptor index
		int num = new Integer(id).intValue();

		// return the descriptor
		return ( DataInputStream ) FileSystemImpl._liste.elementAt(num-1);
	}

	/**
	 * Operation write
	 *
	 * This operation write a buffer into file 	 
	 */
	public int write(byte[] buffer)
	{	
		return 0;
	}

	/**
	 * Operation read
	 *
	 * This operation read a bounded buffer from a file	 
	 *
	 * @param	num_bytes	buffer size
	 */
	public byte[] read(int num_bytes)
	{
		DataInputStream input = getDescriptor();

		byte [] buffer = new byte[num_bytes];

		try
		{
			input.read(buffer,0,num_bytes);
		}
		catch ( java.io.IOException ex )
		{
			System.out.println("Impossible de lire dans le fichier");
			return null;
		}

		return buffer;
	}

	/**
	 * Operation destroy
	 */
	public void destroy()
	{
		// Nothing
	}

}